<?php

namespace Polkurier\Controller;


use Polkurier\ApiClient;
use Polkurier\Exception\HttpException;
use Polkurier\Http\JsonResponse;
use Polkurier\Http\Request;
use Polkurier\Util\Arr;
use PolkurierAddress;

/**
 * Class CourierPointController
 */
class OrderController
{

    const TYPES_MAP = [
        'paczka' => 'box',
        'koperta' => 'envelope',
        'paleta' => 'palette',
    ];

    /**
     * Wycena zamówienia
     * @param Request $request
     * @return JsonResponse
     * @throws HttpException
     */
    public function evaluateAction(Request $request)
    {

        $params = [
            "shipmenttype" => self::TYPES_MAP[$request->getRequest('polkurier_type')],
            "packs" => [],
            'COD' => (float)$request->getRequest('polkurier_pobranie', 0.0),
            'codtype' => $request->getRequest('polkurier_pobranie_zwrot', ''),
            'return_cod' => $request->getRequest('polkurier_pobranie_rodzaj', ''),
            'insurance' => (float)$request->getRequest('polkurier_ubezpieczenie', 0.0),
            'postcode_recipient' => '',
            'postcode_sender' => '',
            'recipient_country' => '',
            'courierservice' => (array)$request->getRequest('courierservice', []),
        ];

        $packagesList = json_decode(stripslashes($request->getRequest('packages_list', '[]')), true);
        foreach ($packagesList as $package) {
            $params['packs'][] = [
                "length" => (float)$package['depth'],
                "width" => (float)$package['width'],
                "height" => (float)$package['height'],
                "weight" => (float)$package['weight'],
                "amount" => (int)$package['count'],
                "type" => $package['nonstandard'] ? "NST" : "ST",
            ];
        }

        $orderId = (int)$request->getRequest('order_id');
        if ($orderId > 0) {
            $order = wc_get_order($orderId);
            if ($order !== false) {
                $orderData = $order->get_data();
                $params['recipient_country'] = $orderData['shipping']['country'];
                $params['postcode_recipient'] = $orderData['shipping']['postcode'];
            }
        }

        $senderAddress = PolkurierAddress::getAddressById((int)$request->getRequest('polkurier_address'));
        if (!empty($senderAddress)) {
            $params["postcode_sender"] = $senderAddress->address['postcode'];
        }

        if (empty($params['packs']) || empty($params['shipmenttype'])) {
            return new JsonResponse([
                'success' => false,
            ]);
        }

        $recipient = (array)$request->getRequest('recipient', []);
        $recipientCountry = Arr::get($recipient, 'country', '');
        if ($recipientCountry !== '') {
            $params['recipient_country'] = $recipientCountry;
        }

        try {
            $response = ApiClient::getInstance()->makeApiRequest('order_valuation', $params);
            return new JsonResponse([
                'success' => true,
                'data' => $response,
            ]);
        } catch (\Exception $e) {
            throw new HttpException($e->getMessage(), 403);
        }
    }


}
